@@ -1,4 +1,5 @@
 from collections import defaultdict
+from functools import wraps
 
 import numpy as np
 import sympy as sym
@@ -8,9 +9,8 @@ from CADETProcess import CADETProcessError
 from CADETProcess.dataStructure import frozen_attributes
 from CADETProcess.dataStructure import StructMeta, UnsignedInteger, String
 from .componentSystem import ComponentSystem
-from .unitOperation import (
-    UnitBaseClass, Source, SourceMixin, Sink, SinkMixin, Cstr
-)
+from .unitOperation import UnitBaseClass
+from .unitOperation import Source, SourceMixin, Sink, SinkMixin, Cstr
 from .binding import NoBinding
 
 
@@ -33,6 +33,7 @@ class FlowSheet(metaclass=StructMeta):
         Connections of UnitOperations.
     output_states : dict
         Split ratios of outgoing streams of UnitOperations.
+
     """
 
     name = String()
@@ -66,10 +67,10 @@ class FlowSheet(metaclass=StructMeta):
     def n_comp(self):
         return self.component_system.n_comp
 
-    def _unit_name_decorator(func):
+    def unit_name_decorator(func):
+        @wraps(func)
         def wrapper(self, unit, *args, **kwargs):
-            """Enable calling functions with unit object or unit name.
-            """
+            """Enable calling functions with unit object or unit name."""
             if isinstance(unit, str):
                 try:
                     unit = self.units_dict[unit]
@@ -79,6 +80,26 @@ class FlowSheet(metaclass=StructMeta):
 
         return wrapper
 
+    def origin_destination_name_decorator(func):
+        @wraps(func)
+        def wrapper(self, origin, destination, *args, **kwargs):
+            """Enable calling functions with origin and destination using names."""
+            if isinstance(origin, str):
+                try:
+                    origin = self.units_dict[origin]
+                except KeyError:
+                    raise CADETProcessError('Not a valid unit')
+
+            if isinstance(destination, str):
+                try:
+                    destination = self.units_dict[destination]
+                except KeyError:
+                    raise CADETProcessError('Not a valid unit')
+
+            return func(self, origin, destination, *args, **kwargs)
+
+        return wrapper
+
     def update_parameters(self):
         for unit in self.units:
             self._parameters[unit.name] = unit.parameters
@@ -96,9 +117,9 @@ class FlowSheet(metaclass=StructMeta):
         }
 
     def update_parameters_decorator(func):
+        @wraps(func)
         def wrapper(self, *args, **kwargs):
-            """Update parameters dict to save time.
-            """
+            """Update parameters dict to save time."""
             results = func(self, *args, **kwargs)
             self.update_parameters()
 
@@ -107,20 +128,17 @@ class FlowSheet(metaclass=StructMeta):
 
     @property
     def units(self):
-        """list: list of all unit_operations in the flow sheet.
-        """
+        """list: list of all unit_operations in the flow sheet."""
         return self._units
 
     @property
     def units_dict(self):
-        """dict: Unit names and objects.
-        """
+        """dict: Unit operation names and objects."""
         return {unit.name: unit for unit in self.units}
 
     @property
     def unit_names(self):
-        """list: Unit names
-        """
+        """list: Names of unit operations."""
         return [unit.name for unit in self.units]
 
     @property
@@ -129,7 +147,7 @@ class FlowSheet(metaclass=StructMeta):
         """
         return len(self._units)
 
-    @_unit_name_decorator
+    @unit_name_decorator
     def get_unit_index(self, unit):
         """Return the unit index of the unit.
 
@@ -147,6 +165,7 @@ class FlowSheet(metaclass=StructMeta):
         -------
         unit_index : int
             Returns the unit index of the unit_operation.
+
         """
         if unit not in self.units:
             raise CADETProcessError('Unit not in flow sheet')
@@ -155,20 +174,17 @@ class FlowSheet(metaclass=StructMeta):
 
     @property
     def sources(self):
-        """list: All UnitOperations implementing the SourceMixin interface.
-        """
+        """list: All UnitOperations implementing the SourceMixin interface."""
         return [unit for unit in self._units if isinstance(unit, SourceMixin)]
 
     @property
     def sinks(self):
-        """list: All UnitOperations implementing the SinkMixin interface.
-        """
+        """list: All UnitOperations implementing the SinkMixin interface."""
         return [unit for unit in self._units if isinstance(unit, SinkMixin)]
 
     @property
     def units_with_binding(self):
-        """list: UnitOperations with binding models.
-        """
+        """list: UnitOperations with binding models."""
         return [unit for unit in self._units
                 if not isinstance(unit.binding_model, NoBinding)]
 
@@ -201,6 +217,7 @@ class FlowSheet(metaclass=StructMeta):
         See Also
         --------
         remove_unit
+
         """
         if not isinstance(unit, UnitBaseClass):
             raise TypeError('Expected UnitOperation')
@@ -229,7 +246,7 @@ class FlowSheet(metaclass=StructMeta):
             self.add_chromatogram_sink(unit)
 
 
-    @_unit_name_decorator
+    @unit_name_decorator
     @update_parameters_decorator
     def remove_unit(self, unit):
         """Remove unit from flow sheet.
@@ -256,6 +273,7 @@ class FlowSheet(metaclass=StructMeta):
         feed_source
         eluent_source
         chromatogram_sink
+
         """
         if unit not in self.units:
             raise CADETProcessError('Unit not in flow sheet')
@@ -288,9 +306,11 @@ class FlowSheet(metaclass=StructMeta):
         --------
         add_connection
         remove_connection
+
         """
         return self._connections
 
+    @origin_destination_name_decorator
     @update_parameters_decorator
     def add_connection(self, origin, destination):
         """Add connection between units 'origin' and 'destination'.
@@ -313,6 +333,7 @@ class FlowSheet(metaclass=StructMeta):
         connections
         remove_connection
         output_state
+
         """
         if origin not in self._units:
             raise CADETProcessError('Origin not in flow sheet')
@@ -327,6 +348,7 @@ class FlowSheet(metaclass=StructMeta):
 
         self.set_output_state(origin, 0)
 
+    @origin_destination_name_decorator
     @update_parameters_decorator
     def remove_connection(self, origin, destination):
         """Remove connection between units 'origin' and 'destination'.
@@ -348,6 +370,7 @@ class FlowSheet(metaclass=StructMeta):
         --------
         connections
         add_connection
+
         """
         if origin not in self._units:
             raise CADETProcessError('Origin not in flow sheet')
@@ -359,8 +382,36 @@ class FlowSheet(metaclass=StructMeta):
             self._connections[destination].origins.remove(origin)
         except KeyError:
             raise CADETProcessError('Connection does not exist.')
-            
+
+    @origin_destination_name_decorator
+    def connection_exists(self, origin, destination):
+        """bool: check if connection exists in flow sheet.
+
+        Parameters
+        ----------
+        origin : UnitBaseClass
+            UnitBaseClass from which the connection originates.
+        destination : UnitBaseClass
+            UnitBaseClass where the connection terminates.
+
+        """
+        if destination in self._connections[origin].destinations \
+                and origin in self._connections[destination].origins:
+            return True
+
+        return False
+
     def check_connections(self):
+        """Validate that units are connected correctly.
+
+        Raises
+        ------
+        CADETProcessError
+            If Inlets have ingoing streams.
+            If Outlets have outgoint streams.
+            If Units (other than Cstr) are not fully connected.
+
+        """
         for unit, connections in self.connections.items():
             if isinstance(unit, Source):
                 if len(connections.origins) != 0:
@@ -396,7 +447,7 @@ class FlowSheet(metaclass=StructMeta):
     def output_states(self):
         return self._output_states
 
-    @_unit_name_decorator
+    @unit_name_decorator
     @update_parameters_decorator
     def set_output_state(self, unit, state):
         """Set split ratio of outgoing streams for UnitOperation.
@@ -415,6 +466,7 @@ class FlowSheet(metaclass=StructMeta):
             If state is integer and the state >= the state_length.
             If the length of the states is unequal the state_length.
             If the sum of the states is not equal to 1.
+
         """
         if unit not in self._units:
             raise CADETProcessError('Unit not in flow sheet')
@@ -494,7 +546,7 @@ class FlowSheet(metaclass=StructMeta):
                         destination_index = self.get_unit_index(destination)
                         value = float(
                             solution['Q_{}_{}'.format(unit_index, destination_index)]
-                        ) 
+                        )
                         destination_flow_rates[unit.name][destination.name][i] = value
                         origin_flow_rates[destination.name][unit.name][i] = value
 
@@ -516,7 +568,7 @@ class FlowSheet(metaclass=StructMeta):
                 )
 
         return flow_rates
-    
+
     def solve_flow_rates(self, source_flow_rates, output_states, coeff=0):
         """Solve flow rates of system using sympy.
 
@@ -538,10 +590,11 @@ class FlowSheet(metaclass=StructMeta):
         solution : dict
             Solution of the flow rates in the system
 
-        Note
-        ----
-        Since dynamic flow rates can be described as cubic polynomials, the
-        flow rates are solved individually for all coefficients.
+        Notes
+        -----
+            Since dynamic flow rates can be described as cubic polynomials, the
+            flow rates are solved individually for all coefficients.
+
         """
         coeffs = np.array(
             [source_flow_rates[unit.name][coeff] for unit in self.sources]
@@ -623,14 +676,13 @@ class FlowSheet(metaclass=StructMeta):
                 raise CADETProcessError(
                     f"Unbalanced flow rate for unit '{unit}'."
                 )
-        
+
     @property
     def feed_sources(self):
-        """list: List of sources considered for calculating recovery yield.
-        """
+        """list: Sources considered for calculating recovery yield."""
         return self._feed_sources
 
-    @_unit_name_decorator
+    @unit_name_decorator
     def add_feed_source(self, feed_source):
         """Add source to list of units to be considered for recovery.
 
@@ -644,6 +696,7 @@ class FlowSheet(metaclass=StructMeta):
         CADETProcessError
             If unit is not in a source object
             If unit is already marked as feed source
+
         """
         if feed_source not in self.sources:
             raise CADETProcessError('Expected Source')
@@ -653,7 +706,7 @@ class FlowSheet(metaclass=StructMeta):
             )
         self._feed_sources.append(feed_source)
 
-    @_unit_name_decorator
+    @unit_name_decorator
     def remove_feed_source(self, feed_source):
         """Remove source from list of units to be considered for recovery.
 
@@ -661,6 +714,7 @@ class FlowSheet(metaclass=StructMeta):
         ----------
         feed_source : SourceMixin
             Unit to be removed from list of feed sources.
+
         """
         if feed_source not in self._feed_sources:
             raise CADETProcessError('Unit \'{}\' is not a feed source.'.format(
@@ -669,11 +723,10 @@ class FlowSheet(metaclass=StructMeta):
 
     @property
     def eluent_sources(self):
-        """list: List of sources to be considered for eluent consumption.
-        """
+        """list: Sources to be considered for eluent consumption."""
         return self._eluent_sources
 
-    @_unit_name_decorator
+    @unit_name_decorator
     def add_eluent_source(self, eluent_source):
         """Add source to list of units to be considered for eluent consumption.
 
@@ -687,6 +740,7 @@ class FlowSheet(metaclass=StructMeta):
         CADETProcessError
             If unit is not in a source object
             If unit is already marked as eluent source
+
         """
         if eluent_source not in self.sources:
             raise CADETProcessError('Expected Source')
@@ -695,7 +749,7 @@ class FlowSheet(metaclass=StructMeta):
                     eluent_source))
         self._eluent_sources.append(eluent_source)
 
-    @_unit_name_decorator
+    @unit_name_decorator
     def remove_eluent_source(self, eluent_source):
         """Remove source from list of units to be considered eluent consumption.
 
@@ -708,6 +762,7 @@ class FlowSheet(metaclass=StructMeta):
         ------
         CADETProcessError
             If unit is not in eluent sources
+
         """
         if eluent_source not in self._eluent_sources:
             raise CADETProcessError('Unit \'{}\' is not an eluent source.'.format(
@@ -716,11 +771,10 @@ class FlowSheet(metaclass=StructMeta):
 
     @property
     def chromatogram_sinks(self):
-        """list: List of sinks to be considered for fractionation.
-        """
+        """list: Sinks to be considered for fractionation."""
         return self._chromatogram_sinks
 
-    @_unit_name_decorator
+    @unit_name_decorator
     def add_chromatogram_sink(self, chromatogram_sink):
         """Add sink to list of units to be considered for fractionation.
 
@@ -734,6 +788,7 @@ class FlowSheet(metaclass=StructMeta):
         CADETProcessError
             If unit is not a sink object.
             If unit is already marked as chromatogram sink.
+
         """
         if chromatogram_sink not in self.sinks:
             raise CADETProcessError('Expected Sink')
@@ -743,7 +798,7 @@ class FlowSheet(metaclass=StructMeta):
             )
         self._chromatogram_sinks.append(chromatogram_sink)
 
-    @_unit_name_decorator
+    @unit_name_decorator
     def remove_chromatogram_sink(self, chromatogram_sink):
         """Remove sink from list of units to be considered for fractionation.
 
@@ -756,6 +811,7 @@ class FlowSheet(metaclass=StructMeta):
         ------
         CADETProcessError
             If unit is not a chromatogram sink.
+
         """
         if chromatogram_sink not in self._chromatogram_sinks:
             raise CADETProcessError(
@@ -818,12 +874,13 @@ class FlowSheet(metaclass=StructMeta):
         Returns
         -------
         unit : UnitBaseClass
-            UnitOperation of flowsheet.
+            UnitOperation of FlowSheet.
 
         Raises
         ------
         KeyError
-            If unit not in flowSheet
+            If unit not in FlowSheet
+
         """
         try:
             return self.units_dict[unit_name]
@@ -832,7 +889,7 @@ class FlowSheet(metaclass=StructMeta):
 
 
     def __contains__(self, item):
-        """Check if an item is part of units.
+        """Check if UnitOperation is part of the FlowSheet.
 
         Parameters
         ----------
@@ -843,9 +900,6 @@ class FlowSheet(metaclass=StructMeta):
         -------
         Bool : True if item is in units, otherwise False.
 
-        Note
-        ----
-        maybe deficient in documentation.
         """
         if (item in self._units) or (item in self.unit_names):
             return True
